Package 'citymix'

Title: Plot a Map on a Map
Description: Create a map of a country with cities from another country, respecting the urban hierarchy.
Authors: Timothée Giraud [aut, cre] (ORCID: <https://orcid.org/0000-0002-1932-3323>)
Maintainer: Timothée Giraud <[email protected]>
License: GPL (>= 3)
Version: 0.1.0
Built: 2026-05-29 19:53:07 UTC
Source: https://codeberg.org/rCarto/citymix

Help Index


Create a map of country with cities from another country

Description

Create a map of a country with cities from another country, respecting the urban hierarchy.

Usage

citymix(x, y, n = 5)

Arguments

x

ISO 3166-1 alpha-3 code of the country to map

y

ISO 3166-1 alpha-3 code of the country used for cities names and populations

n

maximum number of cities to plot

Value

Nothing is returned, a map is plotted

Examples

citymix("FRA", "DZA", n = 5)